@@ -1,7 +1,7 @@
 corc0 <-
 function(datavector,sampsize,dimension,subsampsize,nboot,u,mixties=FALSE,nthreads=2)
 {
-  return( .Call("InterCopulation",
+  return( .Call("InterCopulation", PACKAGE = "subrank",
     as.double(datavector),
     as.integer(sampsize), as.integer(subsampsize), as.integer(dimension),
     as.integer(mixties),
