@@ -1,8 +1,5 @@
 #include <stdlib.h>
 #include <math.h>
-#ifdef _OPENMP
-#include <omp.h>
-#endif
 
 int Suivant(int nbchiffres, int base, int *chiffres);
 
@@ -15,4 +12,5 @@ void TirMultCop(const int *nbobsconnues, const int *nbdimconnues,
   const int *nbdiminc, const int *tailsousech,
   double *unif,
   const double *cop, const int *rangconnues, const int *dimconnues, const int *dimincs,
+  int *inthreads,
   int *rangprevues);
